@@ -29,7 +29,7 @@ import shutil
 
 from tabulate import tabulate
 
-from . import remote
+from .utils import remote
 from .utils.settings import NUTR_ID_KCAL, NUTR_IDS_AMINOS, NUTR_IDS_FLAVONES
 
 
@@ -50,16 +50,26 @@ def search(words, dbs=None):
 def print_results(results):
     # Current terminal size
     # TODO: dynamic buffer
+    # TODO: display "nonzero/total" report nutrients, aminos, and flavones.. sometimes zero values are not useful
     # bufferwidth = shutil.get_terminal_size()[0]
     bufferheight = shutil.get_terminal_size()[1]
 
-    headers = ["food_id", "food_name", "kcal", "# nutrients", "Aminos", "Flavones"]
+    headers = [
+        "food_id",
+        "food_name",
+        "kcal",
+        "# nutrients",
+        "Aminos",
+        "Flavones",
+        "fdgrp_desc",
+    ]
     rows = []
     for i, r in enumerate(results):
         if i == bufferheight - 4:
             break
         food_id = r["food_id"]
         food_name = r["long_desc"][:45]
+        fdgrp_desc = r["fdgrp_desc"]
 
         nutrients = r["nutrients"]
         kcal = nutrients.get(str(NUTR_ID_KCAL))
@@ -71,7 +81,15 @@ def print_results(results):
             [nutrients[n_id] for n_id in nutrients if int(n_id) in NUTR_IDS_FLAVONES]
         )
 
-        row = [food_id, food_name, kcal, len(nutrients), len_aminos, len_flavones]
+        row = [
+            food_id,
+            food_name,
+            kcal,
+            len(nutrients),
+            len_aminos,
+            len_flavones,
+            fdgrp_desc,
+        ]
         rows.append(row)
         # avail_buffer = bufferwidth - len(food_id) - 15
         # if len(food_name) > avail_buffer:
