@@ -27,6 +27,11 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 import os
 
+from dotenv import load_dotenv
+
+# Read in .env file if it exists locally, else look to env vars
+load_dotenv(verbose=True)
+
 NUTRA_DIR = os.path.join(os.path.expanduser("~"), ".nutra")
 
 REMOTE_HOST = "https://nutra-server.herokuapp.com"
@@ -34,3 +39,68 @@ SERVER_HOST = os.getenv("NUTRA_OVERRIDE_LOCAL_SERVER_HOST", REMOTE_HOST)
 
 
 TESTING = SERVER_HOST != REMOTE_HOST
+
+NUTR_ID_KCAL = 208
+
+NUTR_IDS_FLAVONES = [
+    710,
+    711,
+    712,
+    713,
+    714,
+    715,
+    716,
+    734,
+    735,
+    736,
+    737,
+    738,
+    731,
+    740,
+    741,
+    742,
+    743,
+    745,
+    749,
+    750,
+    751,
+    752,
+    753,
+    755,
+    756,
+    758,
+    759,
+    762,
+    770,
+    773,
+    785,
+    786,
+    788,
+    789,
+    791,
+    792,
+    793,
+    794,
+]
+
+NUTR_IDS_AMINOS = [
+    501,
+    502,
+    503,
+    504,
+    505,
+    506,
+    507,
+    508,
+    509,
+    510,
+    511,
+    512,
+    513,
+    514,
+    515,
+    516,
+    517,
+    518,
+    521,
+]
